Range-v3: ranges::v3::with_braced_init_args< ImplFn > Struct Template Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::with_braced_init_args< ImplFn > Struct Template Reference
Utility
Inheritance diagram for ranges::v3::with_braced_init_args< ImplFn >:

## Public Member Functions
template<typename V0 , typename... Args>
constexpr auto | operator() (std::initializer_list< V0 > &&rng0, Args &&...args) const -> decltype(std::declval< ImplFn const &>()(std::move(rng0), std::declval< Args >()...))
template<typename Rng0 , typename V1 , typename... Args>
constexpr auto | operator() (Rng0 &&rng0, std::initializer_list< V1 > &&rng1, Args &&...args) const -> decltype(std::declval< ImplFn const &>()(std::declval< Rng0 >(), std::move(rng1), std::declval< Args >()...))
template<typename V0 , typename V1 , typename... Args>
constexpr auto | operator() (std::initializer_list< V0 > rng0, std::initializer_list< V1 > &&rng1, Args &&...args) const -> decltype(std::declval< ImplFn const &>()(std::move(rng0), std::move(rng1), std::declval< Args >()...))

## Member Function Documentation

## ◆ operator()() [1/2]

template<typename ImplFn >
template<typename Rng0 , typename V1 , typename... Args>

constexpr auto ranges::v3::with_braced_init_args< ImplFn >::operator() | ( | Rng0 && | rng0,
|  | std::initializer_list< V1 > && | rng1,
|  | Args &&... | args
| ) |  | const -> decltype(std::declval<ImplFn const &>()(std::declval<Rng0>(), std::move(rng1), std::declval<Args>()...))

This is an overloaded member function, provided for convenience. It differs from the above function only in what argument(s) it accepts.

References ranges::v3::move.

## ◆ operator()() [2/2]

template<typename ImplFn >
template<typename V0 , typename V1 , typename... Args>

constexpr auto ranges::v3::with_braced_init_args< ImplFn >::operator() | ( | std::initializer_list< V0 > | rng0,
|  | std::initializer_list< V1 > && | rng1,
|  | Args &&... | args
| ) |  | const -> decltype(std::declval<ImplFn const &>()(std::move(rng0), std::move(rng1), std::declval<Args>()...))

This is an overloaded member function, provided for convenience. It differs from the above function only in what argument(s) it accepts.

References ranges::v3::move.